<?php
/**
 * @package        Joomla
 * @subpackage     Helpdesk Pro
 * @author         Tuan Pham Ngoc
 * @copyright      Copyright (C) 2013 - 2023 Ossolution Team
 * @license        GNU/GPL, see LICENSE.php
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\CMS\Uri\Uri;
use OSSolution\HelpdeskPro\Site\Helper\Database as HelpdeskproHelperDatabase;
use OSSolution\HelpdeskPro\Site\Helper\Helper as HelpdeskproHelper;

class plgHelpdeskProAssignticket extends CMSPlugin
{
	/**
	 * Application object.
	 *
	 * @var    JApplicationCms
	 */
	protected $app;

	public function onViewTicket($row)
	{
		HTMLHelper::_('behavior.core');

		$config   = HelpdeskproHelper::getConfig();
		$rowUsers = HelpdeskproHelperDatabase::getAllStaffs($config->staff_group_id);
		$user     = Factory::getUser();

		if (count($rowUsers) && $user->authorise('helpdeskpro.assignticket', 'com_helpdeskpro'))
		{
			Factory::getApplication()->getDocument()
				->addScript(
					Uri::root(true) . '/media/com_helpdeskpro/js/plug_helpdeskpro_assignticket.js',
					['version' => HelpdeskproHelper::getInstalledVersion()]
				)
				->addScriptOptions('ticket_id', $row->id);
			Text::script('HDP_ASSIGN_TICKET_SUCCESS');

			$displayField = $config->get('staff_display_field', 'username') ?: 'username';

			if ($this->app->isClient('site'))
			{
				$bootstrapHelper = HelpdeskProHelperBootstrap::getInstance();
			}
			else
			{
				$bootstrapHelper = HelpdeskProHelperBootstrap::getInstance();
			}

			ob_start();
			?>
			<tr>
				<th colspan="2" class="hdp-assign-ticket-to-staff-heading <?php
				echo $bootstrapHelper->getClassMapping('btn-primary'); ?>"><?php
					echo Text::_('HDP_ASSIGN_TICKET_TO_STAFF'); ?></th>
			</tr>
			<?php
			?>
			<tr>
				<td colspan="2">
					<?php
					$options   = [];
					$options[] = HTMLHelper::_('select.option', 0, Text::_('HDP_SELECT_STAFF'), 'id', $displayField);
					$options   = array_merge($options, $rowUsers);
					echo HelpdeskproHelperHtml::getChoicesJsSelect(
						HTMLHelper::_('select.genericlist', $options, 'user_id', 'class="chosen form-select"', 'id', $displayField, $row->staff_id)
					);
					?>
					<input type="button" id="ajaxButton" value="<?php
					echo Text::_('HDP_ASSIGN') ?>"
					       class="btn btn-primary">
					<img style="display: none;" class="ajax-loading" alt=""
					     src="<?php
					     echo Uri::root(true) . '/plugins/helpdeskpro/assignticket/loading.gif'; ?>"><br>
				</td>
			</tr>
			<?php
			return ob_get_clean();
		}

		return null;
	}
}	